#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.5

$LastChangedRevision: 7384 $
$LastChangedDate:: 2023-11-02 11:19:29 +0100#$

This file is part of SyMSpace.

Copyright (c) 2017, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""

import os
import shutil
import json
import glob

from symspace.wrapper.symwrapper import SymProject

import componentspace.osutils.fileutils as fu
from componentspace.material_utils.ecometric_functions import EcometricFunctions
from componentspace.material_utils.material_functions import GeneralMaterialFunctions
from componentspace.material_utils.batch_material import MaterialBatchComponent


class MaterialNonferrousMetal(MaterialBatchComponent):
    """

    """

    def _createSingleCompfileFromTemplate(self, comp_file: str, material: dict):
        """
        Creates a directory with the name of the geometry and the component class
        Copies directories /rst, /help, and /doc

        Parameters
        ----------
        material : dict
           Dictionary of material properties

        """

        path_material = os.path.dirname(comp_file)
        component_name = material['component_name']

        # Create material directory
        if not os.path.exists(path_material):
            os.mkdir(path_material)

        '''Copy rst'''
        fu.copyFileAndReplace(os.path.join(self.path, 'index.rst'),
                              os.path.join(path_material, 'index.rst'),
                              [('__ComponentTitle__', component_name + '\n' + len(component_name) * '='),
                               ('__Comment__', material['comment']),
                               ('__MaterialName__', material['name']),
                               # ('__MaterialNumber__', material['DIN EN']['value']),
                               ('__Manufacturer__', material['manufacturer']),
                               ('__PDF__', material['pdf_file'])])

        fu.copyTree(os.path.join(self.path, 'rst'), os.path.join(path_material, 'rst'))

        '''Copy pdf'''
        pdf_file = os.path.join(self.path, 'resources', 'rawData', material['pdf_file'])
        if os.path.isfile(pdf_file):
            shutil.copy(pdf_file, os.path.join(path_material, 'rst', material['pdf_file']))

        '''Modify material file'''
        prj = SymProject.load(comp_file)
        
        GeneralMaterialFunctions.set_filter(prj, material)
        GeneralMaterialFunctions.set_info(prj, material)
        GeneralMaterialFunctions.set_general_properties(prj, material)
        GeneralMaterialFunctions.set_electromagnetic_properties(prj, material)
        GeneralMaterialFunctions.set_mechanic_properties(prj, material)
        GeneralMaterialFunctions.set_thermal_properties(prj, material)
        EcometricFunctions.set_ecometric_properties(prj, material)

        prj.save()

    def extractMaterialData(self):
        # Todo: this needs to be cleaned up or re-implemented,
        #  so the functionality is split in smaller methods/functions.
        from componentspace.material_utils.losscoefficient_functions import MaterialFunctions
        from componentspace.material_utils.bhcurve_functions import ExtendBHCurve, BHCurve_correction

        tasks = dict(only_correct=False, only_extend=True,
                     correct_extend=False, extend_correct=False, extend_correct_part=False)

        file_model = os.path.join(self.path, self.name + '.mop')
        if os.path.isfile(file_model):
            self.sym_mdl = SymProject.load(file_model)
        else:
            raise Exception('Model {} file does not exist!'.format(file_model))

        folder_resources = str(os.path.join(self.path, 'resources', 'rawData'))

        '''All Files'''
        all_materials_dictionary = {}

        os.chdir(folder_resources)
        # print(os.getcwd())
        for i, filename in enumerate(glob.glob(folder_resources + "/*.json")):
            print('**** {} ****'.format(filename))

            with open(filename, "r") as json_file:
                data = json.load(json_file)

            all_materials_dictionary[filename] = data

            if 'eco_excel_file' in data:
                eco_excel_files = data['eco_excel_file']
                for eco_excel_file in eco_excel_files:
                    print('eco_excel_file: ', eco_excel_file)
                    eco_xls_data = EcometricFunctions.read_eco_excel_file(os.path.join(folder_resources, eco_excel_file))
                    all_materials_dictionary[filename].update(eco_xls_data)
            else:
                print('No eco-excel-file with ecometrics data was given.')

        for key in all_materials_dictionary.keys():
            material_dictionary = all_materials_dictionary[key]

            json_folder = str(os.path.join(self.path, 'resources'))
            with open(str(os.path.join(json_folder, material_dictionary['component_name'] + ".json")), "w") as f:
                json.dump(material_dictionary, f, indent=4, sort_keys=False)
