#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 7474 $
$LastChangedDate:: 2023-11-27 07:34:55 +0100#$

This file is part of SyMSpace.

Copyright (c) 2020, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
import numpy as np
from lcm.utils.pytperiodic import PyTPeriodicMatrix
from symspace.wrapper.symwrapper import *
import os


prj: SymProject = __project__
obj: SymContainer = __parameter__

path = prj.getDirectory()
param = obj.getParameters('SymParameter')

latex = ''

# Section with header
latex += f'\\section{{{obj.getName()}}}\n\n'

# Table header
latex += r'\begin{tabular}{X>{\raggedleft}p{1.5cm}>{\centering}p{2cm}>{\raggedright}p{2cm}} '
latex += '\n'

# Table
for par in param:
    if hasattr(par, 'getData') and not isinstance(par, SymContainer):
        ident = par.getIdentifier().replace(obj.getIdentifier(), '__self__')
        latex += f'\t{par.getDescription()} & \\SYMPARAM{{{ident}}}{{t}} & \\textbf{{\SYMPARAM{{{ident}}}}} & \\SYMPARAM{{{ident}}}{{u}} \\tabularnewline\n'

# Table end
latex += r'\end{tabular}'
latex += '\n\n'

for par in param:
    if hasattr(par, 'getDocFiles'):
        # Figure
        ident = par.getIdentifier().replace(obj.getIdentifier(), '__self__')
        for doc in par.getDocFiles():
            name = doc['name']
            description = doc['description']
            latex += '\\begin{figure}[H]\n\t\\centering{}\n'
            latex += f'\t\\SYMGRAPHIC{{{ident}({name})}}{{width=10cm}}\n'
            latex += f'\t\\protect\\caption{{{description}.}}\n\\end{{figure}}\n\n'

with open(os.path.join(path, 'docu.tex'), 'w') as fh:
    fh.write(latex)
