# !/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 5027 $
$LastChangedDate:: 2021-10-12 15:12:32 +0200#$

This file is part of SyMSpace.

Copyright (c) 2021, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
import os
import shutil
from abc import ABCMeta
from abc import abstractmethod
import componentspace.osutils.fileutils as fu


class AbstractTestBuilder(metaclass=ABCMeta):
    build_reports_dir = None

    # Todo remove start_path from __init__
    def __init__(self, start_path: str, timeout: float, *args, **kwargs):
        """
        Class collects and builds SyMProject tests for components from scripts

        Parameters
        ----------
        start_path : str
            Path to the directory where build starts.
        timeout : float
            Timeout (in seconds) for single component test build script
        """
        self.start_path = start_path
        self.timeout = timeout
        self.junit_build = kwargs['junit_build']

    def cleanReportsDir(self):
        if os.path.isdir(self.build_reports_dir):
            print('Deleting BuildTest Reports Directory: {}'.format(self.build_reports_dir))
            shutil.rmtree(self.build_reports_dir, onerror=fu.on_rm_error)

    def deployReports(self, clean=True):
        """
        copy unittest files to reports dir


        Parameters
        ----------
        clean : bool
            Remove existing directory first

        """

        if clean:
            self.cleanReportsDir()
            '''only print if folder was deleted first'''
            print("Moving reports to {}".format(self.build_reports_dir))

        if not os.path.isdir(self.build_reports_dir):
            os.makedirs(self.build_reports_dir)

        '''Workaround: save at each step in startBuild() requires to overwrite the file with the absolute path'''
        junit_xml_file = os.path.join(self.build_reports_dir, os.path.basename(self.junit_build.junit_xml_file))
        shutil.move(self.junit_build.junit_xml_file, junit_xml_file)

    @abstractmethod
    def startBuild(self):
        raise NotImplementedError()
